@@ -1,9 +1,9 @@
 is.geom <-
-function(x,a,p0=NULL)
+function(x,a=10,p0=NULL)
 {
 	re=1;
 	for(i in 1:length(x))
-		if(x[i]<0&&round(x)!=x)
+		if(x[i]<0||round(x[i])!=x[i])
 			re=-1;
 	if(re==-1)
 	{
